@@ -36,8 +36,8 @@ class ValidatorsDialog : public KPageDialog
     Q_OBJECT
 
 public:
-    explicit ValidatorsDialog(QWidget *parent = Q_NULLPTR);
-    ~ValidatorsDialog();
+    explicit ValidatorsDialog(QWidget *parent = nullptr);
+    ~ValidatorsDialog() override;
 
 signals:
     void configChanged();
