@@ -34,10 +34,10 @@ public:
     /**
      * Creates an animated logo button which follows the toolbar icon size
      */
-    KonqAnimatedLogo(QWidget *parent = 0);
+    KonqAnimatedLogo(QWidget *parent = nullptr);
 
 protected:
-    void changeEvent(QEvent *event) Q_DECL_OVERRIDE;
+    void changeEvent(QEvent *event) override;
 
 private Q_SLOTS:
     void setAnimatedLogoSize(const QSize &);
