@@ -23,7 +23,6 @@
 
 #include <QMimeDatabase>
 #include <QWebEngineUrlRequestJob>
-#include <QDebug>
 #include <QBuffer>
 
 #include <KIO/StoredTransferJob>
@@ -35,7 +34,7 @@ void WebEnginePartKIOHandler::requestStarted(QWebEngineUrlRequestJob *req)
 }
 
 WebEnginePartKIOHandler::WebEnginePartKIOHandler(QObject* parent):
-    QWebEngineUrlSchemeHandler(parent), m_embedder(Q_NULLPTR)
+    QWebEngineUrlSchemeHandler(parent), m_embedder(nullptr)
 {
     connect(this, &WebEnginePartKIOHandler::ready, this, &WebEnginePartKIOHandler::sendReply);
 }
