@@ -70,7 +70,7 @@ public:
      *
      * @param  req: the request job
      */
-    void requestStarted(QWebEngineUrlRequestJob* req) Q_DECL_OVERRIDE;
+    void requestStarted(QWebEngineUrlRequestJob* req) override;
     
 protected slots:
     
@@ -156,7 +156,7 @@ protected:
      * This function can be called by derived classes from their implementation of
      * processSlaveOutput().
      * 
-     * @param messsage the new error message. If error() is not `QWebEngineUrlRequestJob::NoError`, this
+     * @param message the new error message. If error() is not `QWebEngineUrlRequestJob::NoError`, this
      *  should not be empty
      */
     inline void setErrorMessage(const QString &message) {m_errorMessage = message;}
@@ -178,12 +178,12 @@ protected:
      * 
      * @param data: the new data
      */
-    inline void setData(const QByteArray data) {m_data = data;}
+    inline void setData(const QByteArray& data) {m_data = data;}
     
     /**
      * @brief The mime type of the data
      * 
-     * This value (actually, it's `name`) will be passed to `QWebEngineUrlRequestJob::reply
+     * This value (actually, it's `name`) will be passed to QWebEngineUrlRequestJob::reply
      * @return The mime type of the data
      */
     inline QMimeType mimeType() const {return m_mimeType;}
