@@ -29,13 +29,10 @@
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <KApplication>
 #include <KAboutData>
-#include <KCmdLineArgs>
 #include <QDebug>
 #include <KIO/AccessManager>
 #include <KUriFilter>
-#include <KInputDialog>
 #include <KLineEdit>
 #include <webenginepart.h>
 
@@ -339,7 +336,7 @@ public slots:
             } else
                 loadNext();
         } else
-            disconnect(m_view, 0, this, 0);
+            disconnect(m_view, nullptr, this, nullptr);
     }
 
 private:
